@@ -1,13 +1,20 @@
+from time import time
 from .domain.exceptions.instrument_not_found import InstrumentNotFoundException
 from .logging import log
 from .api_client.api_client import ApiClient
 
 
 class SDK:
-    def __init__(self, host, port, log_level="WARNING", default_string_response_conversion="double", default_bytearray_response_conversion="bytes"):
+    def __init__(self, log_level="WARNING", default_string_response_conversion="double", default_bytearray_response_conversion="bytes"):
         log.set_level(log_level)
         log.info("Initializating SDK")
-        self._client = ApiClient(host, int(port), str(default_string_response_conversion), str(default_bytearray_response_conversion))
+        self._client = ApiClient(str(default_string_response_conversion), str(default_bytearray_response_conversion))
+
+    def connect_through_TCP(self, host, port):
+        self._client.connect_through_TCP(host, int(port))
+
+    def connect_through_RS232(self):
+        self._client.connect_through_RS232()
 
     def disconnect(self):
         self._client.disconnect()
